@@ -260,7 +260,7 @@
 #'  (at least that is how my 2010 version behaves). You can additinally use the
 #'  \code{options(htmlTableCompat = "html")} if you want a change to apply
 #'  to the entire document.
-#' @param escape.html logical: should HTML characters be escaped? Defaults to TRUE.
+#' @param escape.html logical: should HTML characters be escaped? Defaults to FALSE.
 #' @return \code{string} Returns a string of class htmlTable
 #'
 #' @example inst/examples/htmlTable_example.R
@@ -338,7 +338,7 @@ htmlTable.default <- function(x,
                               ctable = TRUE,
                               compatibility = getOption("htmlTableCompat", "LibreOffice"),
                               cspan.rgroup = "all",
-                              escape.html = TRUE,
+                              escape.html = FALSE,
                               ...)
 {
   if (isTRUE(escape.html)) {
@@ -1054,9 +1054,9 @@ knit_print.htmlTable<- function(x, ...){
 #'  the table within that is envoced if in \code{\link[base]{interactive}} mode.
 #'  Set this to \code{FALSE} if you want to remove that  functionality. You can
 #'  also force the function to call a specific viewer by setting this to a
-#'  viewer function, e.g. \code{useViewer = utils::browseUrl} if you want to
+#'  viewer function, e.g. \code{useViewer = utils::browseURL} if you want to
 #'  override the default RStudio viewer. Another option that does the same is to
-#'  set the \code{options(viewer=utils::browseUrl)} and it will default to that
+#'  set the \code{options(viewer=utils::browseURL)} and it will default to that
 #'  particular viewer (this is how RStudio decides on a viewer).
 #'  \emph{Note:} If you want to force all output to go through the
 #'  \code{\link[base]{cat}()} the set \code{\link[base]{options}(htmlTable.cat = TRUE)}.
